@@ -1,6 +1,10 @@
 import requests
 from typing import Callable, TypeVar, get_type_hints, Type
-from xwire.rest._private.utils import deserialize, get_cookies
+import xwire.transport
+from xwire.common import decorator_utils
+from xwire.rest._private.utils import get_cookies
+from xwire.rest._private.proxy.decorators import resource
+
 
 T = TypeVar('T')
 
@@ -10,7 +14,7 @@ def _do_get(url: str, return_class: Type[T], **kwargs) -> T:
     if response.status_code >= 400:
         response.raise_for_status()
     elif return_class is not None:
-        return deserialize(response.json(), return_class)
+        return xwire.transport.json.deserialize(response.json(), return_class)
     else:
         return None
 
@@ -20,7 +24,8 @@ def get(path: str):
         return_type = get_type_hints(func)['return']
 
         def wrapper(self, *args):
-            url = self.base_url + self._proxy['_resource_path'] + path
+            resource_metadata = decorator_utils.get_decorator_metadata(self, resource)
+            url = self.base_url + resource_metadata['resource_path'] + path
             return _do_get(url, return_type, cookies=get_cookies(self))
 
         return wrapper
